@@ -1,4 +1,26 @@
-(* $Id: gMisc.mli,v 1.40 2004/08/27 19:16:55 oandrieu Exp $ *)
+(**************************************************************************)
+(*                Lablgtk                                                 *)
+(*                                                                        *)
+(*    This program is free software; you can redistribute it              *)
+(*    and/or modify it under the terms of the GNU Library General         *)
+(*    Public License as published by the Free Software Foundation         *)
+(*    version 2, with the exception described in file COPYING which       *)
+(*    comes with the library.                                             *)
+(*                                                                        *)
+(*    This program is distributed in the hope that it will be useful,     *)
+(*    but WITHOUT ANY WARRANTY; without even the implied warranty of      *)
+(*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the       *)
+(*    GNU Library General Public License for more details.                *)
+(*                                                                        *)
+(*    You should have received a copy of the GNU Library General          *)
+(*    Public License along with this program; if not, write to the        *)
+(*    Free Software Foundation, Inc., 59 Temple Place, Suite 330,         *)
+(*    Boston, MA 02111-1307  USA                                          *)
+(*                                                                        *)
+(*                                                                        *)
+(**************************************************************************)
+
+(* $Id: gMisc.mli 1357 2007-08-09 12:32:26Z ben_99_9 $ *)
 
 open Gtk
 open GObj
@@ -32,13 +54,16 @@ class statusbar_context :
     @gtkdoc gtk GtkStatusbar *)
 class statusbar : Gtk.statusbar obj ->
   object
-    inherit GContainer.container_full
+    inherit GPack.box
     val obj : Gtk.statusbar obj
     method new_context : name:string -> statusbar_context
+    method has_resize_grip : bool
+    method set_has_resize_grip : bool -> unit
   end
 
 (** @gtkdoc gtk GtkStatusbar *)
 val statusbar :
+  ?has_resize_grip:bool ->
   ?border_width:int ->
   ?width:int ->
   ?height:int ->
@@ -166,6 +191,7 @@ class image : 'a obj ->
     inherit misc
     constraint 'a = [> Gtk.image]
     val obj : 'a obj
+    method clear : unit -> unit (** since Gtk 2.8 *)
     method storage_type : image_type
     method set_image : Gdk.image -> unit
     method set_pixmap : GDraw.pixmap -> unit
@@ -175,10 +201,12 @@ class image : 'a obj ->
     method set_stock : GtkStock.id -> unit
     method set_icon_set : icon_set -> unit
     method set_icon_size : Tags.icon_size -> unit
+    method set_pixel_size : int -> unit
     method image : Gdk.image
     method pixmap : GDraw.pixmap
     method mask : Gdk.bitmap option
     method pixbuf : GdkPixbuf.pixbuf
+    method pixel_size : int
     method stock : GtkStock.id
     method icon_set : icon_set
     method icon_size : Tags.icon_size
@@ -189,6 +217,7 @@ val image :
   ?file:string ->
   ?image:Gdk.image ->
   ?pixbuf:GdkPixbuf.pixbuf ->
+  ?pixel_size:int ->
   ?pixmap:Gdk.pixmap ->
   ?mask:Gdk.bitmap ->
   ?stock:GtkStock.id ->
@@ -243,6 +272,17 @@ class label_skel : 'a obj ->
     method text : string
     method use_markup : bool
     method use_underline : bool
+
+    method angle : float (** @since GTK 2.6 *)
+    method set_angle : float -> unit (** @since GTK 2.6 *)
+    method max_width_chars : int (** @since GTK 2.6 *)
+    method set_max_width_chars : int -> unit (** @since GTK 2.6 *)
+    method single_line_mode : bool (** @since GTK 2.6 *)
+    method set_single_line_mode : bool -> unit (** @since GTK 2.6 *)
+    method width_chars : int (** @since GTK 2.6 *)
+    method set_width_chars : int -> unit (** @since GTK 2.6 *)
+    method ellipsize : PangoEnums.ellipsize_mode (** @since GTK 2.6 *)
+    method set_ellipsize : PangoEnums.ellipsize_mode -> unit (** @since GTK 2.6 *)
   end
 
 (** A widget that displays a small to medium amount of text
@@ -269,6 +309,7 @@ val label :
   ?line_wrap:bool ->
   ?pattern:string ->
   ?selectable:bool ->
+  ?ellipsize:PangoEnums.ellipsize_mode ->
   ?xalign:float ->
   ?yalign:float ->
   ?xpad:int ->
