@@ -1,4 +1,26 @@
-(* $Id: glib.ml,v 1.30 2005/08/18 12:47:28 oandrieu Exp $ *)
+(**************************************************************************)
+(*                Lablgtk                                                 *)
+(*                                                                        *)
+(*    This program is free software; you can redistribute it              *)
+(*    and/or modify it under the terms of the GNU Library General         *)
+(*    Public License as published by the Free Software Foundation         *)
+(*    version 2, with the exception described in file COPYING which       *)
+(*    comes with the library.                                             *)
+(*                                                                        *)
+(*    This program is distributed in the hope that it will be useful,     *)
+(*    but WITHOUT ANY WARRANTY; without even the implied warranty of      *)
+(*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the       *)
+(*    GNU Library General Public License for more details.                *)
+(*                                                                        *)
+(*    You should have received a copy of the GNU Library General          *)
+(*    Public License along with this program; if not, write to the        *)
+(*    Free Software Foundation, Inc., 59 Temple Place, Suite 330,         *)
+(*    Boston, MA 02111-1307  USA                                          *)
+(*                                                                        *)
+(*                                                                        *)
+(**************************************************************************)
+
+(* $Id: glib.ml 1355 2007-08-08 13:17:06Z ben_99_9 $ *)
 
 type unichar = int
 type unistring = unichar array
@@ -318,3 +340,5 @@ external get_user_data_dir : unit -> string = "ml_g_get_user_data_dir"
 external get_user_config_dir : unit -> string = "ml_g_get_user_config_dir"
 external get_system_data_dirs : unit -> string list = "ml_g_get_system_data_dirs"
 external get_system_config_dirs : unit -> string list = "ml_g_get_system_config_dirs"
+
+external usleep : int -> unit = "ml_g_usleep"
