@@ -1,24 +1,48 @@
-(* $Id: gtkList.ml,v 1.21 2001/09/06 08:47:56 garrigue Exp $ *)
+(**************************************************************************)
+(*                Lablgtk                                                 *)
+(*                                                                        *)
+(*    This program is free software; you can redistribute it              *)
+(*    and/or modify it under the terms of the GNU Library General         *)
+(*    Public License as published by the Free Software Foundation         *)
+(*    version 2, with the exception described in file COPYING which       *)
+(*    comes with the library.                                             *)
+(*                                                                        *)
+(*    This program is distributed in the hope that it will be useful,     *)
+(*    but WITHOUT ANY WARRANTY; without even the implied warranty of      *)
+(*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the       *)
+(*    GNU Library General Public License for more details.                *)
+(*                                                                        *)
+(*    You should have received a copy of the GNU Library General          *)
+(*    Public License along with this program; if not, write to the        *)
+(*    Free Software Foundation, Inc., 59 Temple Place, Suite 330,         *)
+(*    Boston, MA 02111-1307  USA                                          *)
+(*                                                                        *)
+(*                                                                        *)
+(**************************************************************************)
+
+(* $Id: gtkList.ml 1347 2007-06-20 07:40:34Z guesdon $ *)
 
 open StdLabels
 open Gaux
 open Gtk
 open Tags
+open GtkListProps
 open GtkBase
 
+external _gtklist_init : unit -> unit = "ml_gtklist_init"
+let () = _gtklist_init ()
+
 module ListItem = struct
-  let cast w : list_item obj = Object.try_cast w "GtkListItem"
-  external create : unit -> list_item obj = "ml_gtk_list_item_new"
+  include ListItem
   external create_with_label : string -> list_item obj
       = "ml_gtk_list_item_new_with_label"
   let create ?label () =
-    match label with None -> create ()
+    match label with None -> create []
     | Some label -> create_with_label label
 end
 
 module Liste = struct
-  let cast w : liste obj = Object.try_cast w "GtkList"
-  external create : unit -> liste obj = "ml_gtk_list_new"
+  include Liste
   external insert_item :
       [>`list] obj -> [>`listitem] obj -> pos:int -> unit
       = "ml_gtk_list_insert_item"
@@ -39,21 +63,10 @@ module Liste = struct
       = "ml_gtk_list_unselect_child"
   external child_position : [>`list] obj -> [>`listitem] obj -> int
       = "ml_gtk_list_child_position"
-  external set_selection_mode : [>`list] obj -> selection_mode -> unit
-      = "ml_gtk_list_set_selection_mode"
-  module Signals = struct
-    open GtkSignal
-    let selection_changed : ([>`list],_) t =
-      { name = "selection_changed"; marshaller = marshal_unit }
-    let select_child : ([>`list],_) t =
-      { name = "select_child"; marshaller = Widget.Signals.marshal }
-    let unselect_child : ([>`list],_) t =
-      { name = "unselect_child"; marshaller = Widget.Signals.marshal }
-  end
 end
 
 module CList = struct
-  let cast w : clist obj = Object.try_cast w "GtkCList"
+  include Clist
   external create : cols:int -> clist obj = "ml_gtk_clist_new"
   external create_with_titles : string array -> clist obj
       = "ml_gtk_clist_new_with_titles"
@@ -147,10 +160,10 @@ module CList = struct
       string -> int -> Gdk.pixmap -> Gdk.bitmap Gpointer.optboxed -> unit
       = "ml_gtk_clist_set_pixtext_bc" "ml_gtk_clist_set_pixtext"
   external set_foreground :
-      [>`clist] obj -> row:int -> Gdk.Color.t Gpointer.optboxed -> unit
+      [>`clist] obj -> row:int -> Gdk.color Gpointer.optboxed -> unit
       = "ml_gtk_clist_set_foreground"
   external set_background :
-      [>`clist] obj -> row:int -> Gdk.Color.t Gpointer.optboxed -> unit
+      [>`clist] obj -> row:int -> Gdk.color Gpointer.optboxed -> unit
       = "ml_gtk_clist_set_background"
   external get_cell_style : [>`clist] obj -> int -> int -> Gtk.style
       = "ml_gtk_clist_get_cell_style"
@@ -211,20 +224,14 @@ module CList = struct
   let set_titles_active w = function
       true -> column_titles_active w
     | false -> column_titles_passive w
-  let set ?hadjustment ?vadjustment ?shadow_type
-      ?(button_actions=[]) ?selection_mode ?reorderable
-      ?use_drag_icons ?row_height ?titles_show ?titles_active w =
-    let may_set f param = may param ~f:(f w) in
-    may_set set_hadjustment hadjustment;
-    may_set set_vadjustment vadjustment;
-    may_set set_shadow_type shadow_type;
-    List.iter button_actions ~f:(fun (n,act) -> set_button_actions w n act);
-    may_set set_selection_mode selection_mode;
-    may_set set_reorderable reorderable;
-    may_set set_use_drag_icons use_drag_icons;
-    may_set set_row_height row_height;
-    may_set set_titles_show titles_show;
-    may_set set_titles_active titles_active
+  let setter ~cont ?hadjustment ?vadjustment ?(button_actions=[])
+      ?titles_show =
+    cont (fun w ->
+      let may_set f param = may param ~f:(f w) in
+      may_set set_hadjustment hadjustment;
+      may_set set_vadjustment vadjustment;
+      List.iter button_actions ~f:(fun (n,act) -> set_button_actions w n act);
+      may_set set_titles_show titles_show)
   let set_sort w ?auto ?column ?dir:sort_type () =
     may auto ~f:(set_auto_sort w);
     may column ~f:(set_sort_column w);
@@ -262,34 +269,14 @@ module CList = struct
     may_set set_background  background;
     may_set set_selectable  selectable;
     may_set set_row_style style
-  module Signals = struct
-    open GtkArgv
-    open GtkSignal
-    let marshal_select f argv = function
-      | INT row :: INT column :: POINTER p :: _ ->
-          let event : GdkEvent.Button.t option =
-	    may_map ~f:GdkEvent.unsafe_copy p
-          in
-          f ~row ~column ~event
-      | _ -> invalid_arg "GtkList.CList.Signals.marshal_select"
-    let select_row : ([>`clist],_) t =
-      { name = "select_row"; marshaller = marshal_select }
-    let unselect_row : ([>`clist],_) t =
-      { name = "unselect_row"; marshaller = marshal_select }
-    let click_column : ([>`clist],_) t =
-      { name = "click_column"; marshaller = marshal_int }
-    external val_scroll_type : int -> scroll_type = "ml_Val_scroll_type"
-    let marshal_scroll f argv = function
-      | INT st :: FLOAT (pos : clampf) :: _ ->
-          f (val_scroll_type st) ~pos
-      | _ -> invalid_arg "GtkList.CList.Signals.marshal_scroll"
-    let scroll_horizontal : ([>`clist],_) t =
-      { name = "scroll_horizontal"; marshaller = marshal_scroll }
-    let scroll_vertical : ([>`clist],_) t =
-      { name = "scroll_vertical"; marshaller = marshal_scroll }
-    external emit_scroll :
-        'a obj -> name:string -> Tags.scroll_type -> pos:clampf -> unit
-        = "ml_gtk_signal_emit_scroll"
-    let emit_scroll = emit ~emitter:emit_scroll
-  end
+
+  external get_row_state :
+      [>`clist] obj -> int -> Gtk.Tags.state_type
+	  = "ml_gtk_clist_get_row_state"
+
+  let emit_scroll =
+    GtkSignal.emit ~conv:ignore ~emitter:
+      (fun ~cont t ~(pos:clampf) ->
+        cont [|`INT(Gpointer.encode_variant GtkEnums.scroll_type t);
+               `FLOAT pos|])
 end
